@@ -17,18 +17,18 @@ echo ""
 echo "[Desktop Action Play]"
 echo "Exec=parole --play"
 echo "_Name=Play/Pause"
-echo "Icon=media-playback-start"
+echo "Icon=media-playback-start-symbolic"
 echo "OnlyShowIn=Unity;"
 echo ""
 echo "[Desktop Action Previous]"
-echo "Exec=parole --previous-track"
+echo "Exec=parole --previous"
 echo "_Name=Previous Track"
-echo "Icon=media-skip-backward"
+echo "Icon=media-skip-backward-symbolic"
 echo "OnlyShowIn=Unity;"
 echo ""
 echo "[Desktop Action Next]"
-echo "Exec=parole --next-track"
+echo "Exec=parole --next"
 echo "_Name=Next Track"
-echo "Icon=media-skip-forward"
+echo "Icon=media-skip-forward-symbolic"
 echo "OnlyShowIn=Unity;"
-echo ""
\ No newline at end of file
+echo ""
