@@ -1,5 +1,7 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -64,24 +66,25 @@ typedef struct _ParoleStreamClass ParoleStreamClass;
 
 struct _ParoleStream
 {
-    GObject         		parent;
+    GObject             parent;
     
 };
 
 struct _ParoleStreamClass
 {
-    GObjectClass 		parent_class;
+    GObjectClass        parent_class;
 };
 
-GType        			parole_stream_get_type        (void) G_GNUC_CONST;
+GType                   parole_stream_get_type          (void) G_GNUC_CONST;
 
-void parole_stream_set_image (GObject *object, GdkPixbuf *pixbuf);
+void                    parole_stream_set_image         (GObject *object, 
+                                                         GdkPixbuf *pixbuf);
 
-GdkPixbuf *parole_stream_get_image (GObject *object);
+GdkPixbuf              *parole_stream_get_image         (GObject *object);
 
-ParoleStream       	       *parole_stream_new             (void);
+ParoleStream           *parole_stream_new               (void);
 
-void			        parole_stream_init_properties (ParoleStream *stream);
+void                    parole_stream_init_properties   (ParoleStream *stream);
 
 G_END_DECLS
 
