@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -33,10 +33,10 @@
 
 #include "parole-module.h"
 
-static void     parole_provider_module_plugin_init   (ParoleProviderPluginIface	 *iface);
+static void     parole_provider_module_plugin_init   (ParoleProviderPluginIface  *iface);
 
 static void     parole_provider_module_class_init    (ParoleProviderModuleClass  *klass);
-static void	parole_provider_module_init 	     (ParoleProviderModule *module);
+static void     parole_provider_module_init          (ParoleProviderModule *module);
 
 GType
 parole_provider_module_get_type (void)
@@ -45,29 +45,29 @@ parole_provider_module_get_type (void)
 
     if (G_UNLIKELY (type == G_TYPE_INVALID))
     {
-	static const GTypeInfo info =
-	{
-	    sizeof (ParoleProviderModuleClass),
-	    NULL,
-	    NULL,
-	    (GClassInitFunc) parole_provider_module_class_init,
-	    NULL,
-	    NULL,
-	    sizeof (ParoleProviderModule),
-	    0,
-	    (GInstanceInitFunc) parole_provider_module_init,
-	    NULL,
-	};
+        static const GTypeInfo info =
+        {
+            sizeof (ParoleProviderModuleClass),
+            NULL,
+            NULL,
+            (GClassInitFunc) parole_provider_module_class_init,
+            NULL,
+            NULL,
+            sizeof (ParoleProviderModule),
+            0,
+            (GInstanceInitFunc) parole_provider_module_init,
+            NULL,
+        };
 
-	static const GInterfaceInfo plugin_info =
-	{
-	    (GInterfaceInitFunc) parole_provider_module_plugin_init,
-	    NULL,
-	    NULL,
-	};
+        static const GInterfaceInfo plugin_info =
+        {
+            (GInterfaceInitFunc) parole_provider_module_plugin_init,
+            NULL,
+            NULL,
+        };
 
-	type = g_type_register_static (G_TYPE_TYPE_MODULE, "ParoleProviderModule", &info, 0);
-	g_type_add_interface_static (type, PAROLE_TYPE_PROVIDER_PLUGIN, &plugin_info);
+        type = g_type_register_static (G_TYPE_TYPE_MODULE, "ParoleProviderModule", &info, 0);
+        g_type_add_interface_static (type, PAROLE_TYPE_PROVIDER_PLUGIN, &plugin_info);
     }
 
     return type;
@@ -84,16 +84,16 @@ parole_module_load (GTypeModule *gtype_module)
 
     if ( G_UNLIKELY (module->library == NULL) )
     {
-	g_critical ("Failed to load plugin : %s", g_module_error ());
-	return FALSE;
+        g_critical ("Failed to load plugin : %s", g_module_error ());
+        return FALSE;
     }
     
     if ( !g_module_symbol (module->library, "parole_plugin_initialize", (gpointer) &module->initialize) || 
          !g_module_symbol (module->library, "parole_plugin_shutdown", (gpointer) &module->shutdown))
     {
-	g_critical ("Plugin %s missing required symbols", gtype_module->name);
-	g_module_close (module->library);
-	return FALSE;
+        g_critical ("Plugin %s missing required symbols", gtype_module->name);
+        g_module_close (module->library);
+        return FALSE;
     }
     
     TRACE ("Loading module %s", gtype_module->name);
@@ -101,6 +101,8 @@ parole_module_load (GTypeModule *gtype_module)
     module->provider_type = (*module->initialize) (module);
     module->active = TRUE;
     
+    TRACE ("Finished loading module %s", gtype_module->name);
+    
     return TRUE;
 }
 
@@ -143,8 +145,8 @@ parole_provider_module_get_is_configurable (ParoleProviderPlugin *plugin)
     module = PAROLE_PROVIDER_MODULE (plugin);
     
     if ( module->instance )
-	return parole_provider_plugin_get_is_configurable (module->instance);
-	
+        return parole_provider_plugin_get_is_configurable (module->instance);
+    
     return FALSE;
 }
 
@@ -156,7 +158,7 @@ parole_provider_module_configure (ParoleProviderPlugin *plugin, GtkWidget *paren
     module = PAROLE_PROVIDER_MODULE (plugin);
     
     if ( module->instance )
-	parole_provider_plugin_configure (module->instance, parent);
+        parole_provider_plugin_configure (module->instance, parent);
 }
 
 static void     
@@ -191,27 +193,36 @@ parole_provider_module_new (const gchar *filename, const gchar *desktop_file)
     
     module->desktop_file = g_strdup (desktop_file);
     g_object_set_data_full (G_OBJECT (module), "desktop-file", 
-			     module->desktop_file, (GDestroyNotify) g_free);
+                 module->desktop_file, (GDestroyNotify) g_free);
     
     return module;
 }
 
-
-void parole_provider_module_new_plugin (ParoleProviderModule *module)
+/**
+ * parole_provider_module_new_plugin:
+ * @module : The #ParoleProviderModule that is being initialized.
+ *
+ * Initialize the #ParoleProviderModule plugin. Return #TRUE if successful.
+ **/
+gboolean parole_provider_module_new_plugin (ParoleProviderModule *module)
 {
     TRACE ("start");
     
-    g_return_if_fail (PAROLE_IS_PROVIDER_MODULE (module));
+    g_return_val_if_fail (PAROLE_IS_PROVIDER_MODULE (module), FALSE);
     
 #ifdef debug
-    g_return_if_fail (module->active == TRUE);
-    g_return_if_fail (module->instance == NULL);
-    g_return_if_fail (module->player == NULL);
+    g_return_val_if_fail (module->active == TRUE, FALSE);
+    g_return_val_if_fail (module->instance == NULL, FALSE);
+    g_return_val_if_fail (module->player == NULL, FALSE);
 #endif
 
     module->instance = g_object_new (module->provider_type, NULL);
+    g_return_val_if_fail (PAROLE_IS_PROVIDER_PLUGIN (PAROLE_PROVIDER_PLUGIN (module->instance)), FALSE);
+
     module->player = parole_plugin_player_new ();
     parole_provider_plugin_set_player (PAROLE_PROVIDER_PLUGIN (module->instance), PAROLE_PROVIDER_PLAYER (module->player));
+    
+    return TRUE;
 }
 
 void parole_provider_module_free_plugin (ParoleProviderModule *module)
@@ -222,14 +233,14 @@ void parole_provider_module_free_plugin (ParoleProviderModule *module)
     
     if ( module->instance )
     {
-	g_object_unref (module->instance);
-	module->instance = NULL;
+        g_object_unref (module->instance);
+        module->instance = NULL;
     }
     
     if ( module->player )
     {
-	g_object_unref (module->player);
-	module->player = NULL;
+        g_object_unref (module->player);
+        module->player = NULL;
     }
 }
 
