@@ -48,30 +48,30 @@ struct ParolePluginPlayerPrivate
 {
     GtkWidget *gst;
     GtkWidget *box;
-    
+
     gulong state_changed;
     gulong tag_message;
     gulong seeked;
     gboolean packed;
-    
+
     gboolean fullscreen;
 
 };
 
 G_DEFINE_TYPE_WITH_CODE (ParolePluginPlayer, parole_plugin_player, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (PAROLE_TYPE_PROVIDER_PLAYER, parole_plugin_player_iface_init))
-                         
+
 static void
 parole_plugin_player_send_message (const gchar *message)
 {
     DBusGProxy *proxy;
-    
+
     proxy = parole_get_proxy (PAROLE_DBUS_PATH, PAROLE_DBUS_INTERFACE);
-    
+
     dbus_g_proxy_call_no_reply (proxy, message,
                                 G_TYPE_INVALID,
                                 G_TYPE_INVALID);
-    
+
     g_object_unref (proxy);
 }
 
@@ -79,36 +79,36 @@ static GtkWidget *
 parole_plugin_player_get_main_window (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
     return gtk_widget_get_toplevel (player->priv->gst);
 }
 
 static void
-parole_plugin_player_pack_widget (ParoleProviderPlayer *provider, GtkWidget *widget, 
+parole_plugin_player_pack_widget (ParoleProviderPlayer *provider, GtkWidget *widget,
                                   const gchar *title, ParolePluginContainer container_type)
 {
     ParolePluginPlayer *player;
     ParolePluginsManager *manager;
-    
+
     manager = parole_plugins_manager_get ();
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     g_return_if_fail (player->priv->packed == FALSE);
-    
+
     player->priv->packed = TRUE;
     player->priv->box = widget;
-    
+
     parole_plugins_manager_pack (manager, widget, title, container_type);
 }
 
-static ParoleState 
+static ParoleState
 parole_plugin_player_get_state (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     return parole_gst_get_state (PAROLE_GST (player->priv->gst));
 }
 
@@ -116,86 +116,86 @@ static const ParoleStream *
 parole_plugin_player_get_stream (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     return parole_gst_get_stream (PAROLE_GST (player->priv->gst));
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_play_uri (ParoleProviderPlayer *provider, const gchar *uri)
 {
     ParoleMediaList *list;
 
     list = PAROLE_MEDIA_LIST (parole_media_list_get ());
     parole_media_list_open_uri (list, uri);
-    
+
     g_object_unref (list);
-    
+
     return TRUE;
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_pause (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     parole_gst_pause (PAROLE_GST (player->priv->gst));
-    
+
     return TRUE;
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_resume (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     parole_gst_resume (PAROLE_GST (player->priv->gst));
-    
+
     return TRUE;
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_stop (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     parole_gst_stop (PAROLE_GST (player->priv->gst));
-    
+
     return TRUE;
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_play_previous (ParoleProviderPlayer *provider)
 {
     parole_plugin_player_send_message ("PrevTrack");
-    
+
     return TRUE;
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_play_next (ParoleProviderPlayer *provider)
 {
     parole_plugin_player_send_message ("NextTrack");
-    
+
     return TRUE;
 }
 
-static gboolean 
+static gboolean
 parole_plugin_player_seek (ParoleProviderPlayer *provider, gdouble pos)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     parole_gst_seek (PAROLE_GST (player->priv->gst), pos);
-    
+
     return TRUE;
 }
 
@@ -204,11 +204,11 @@ parole_plugin_player_get_stream_position (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
     gdouble position = 0;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
 
     position = parole_gst_get_stream_position (PAROLE_GST (player->priv->gst));
-    
+
     /* Return as microseconds */
     return position*1000000.0;
 }
@@ -219,11 +219,11 @@ static void parole_plugin_player_open_media_chooser (ParoleProviderPlayer *provi
 
     list = PAROLE_MEDIA_LIST (parole_media_list_get ());
     parole_media_list_open (list);
-    
+
     g_object_unref (list);
 }
 
-static GtkAction* parole_plugin_player_get_action (ParoleProviderPlayer *provider, ParolePlayerAction action)
+static GSimpleAction* parole_plugin_player_get_action (ParoleProviderPlayer *provider, ParolePlayerAction action)
 {
     return parole_player_get_action (action);
 }
@@ -231,23 +231,23 @@ static GtkAction* parole_plugin_player_get_action (ParoleProviderPlayer *provide
 static gboolean parole_plugin_player_get_fullscreen (ParoleProviderPlayer *provider)
 {
     ParolePluginPlayer *player;
-    
+
     player = PAROLE_PLUGIN_PLAYER (provider);
-    
+
     return player->priv->fullscreen;
 }
 
 static gboolean parole_plugin_player_set_fullscreen (ParoleProviderPlayer *provider, gboolean fullscreen)
 {
     GtkWidget *window;
-    
+
     window = parole_plugin_player_get_main_window (provider);
-    
+
     if (fullscreen)
         gtk_window_fullscreen(GTK_WINDOW(window));
     else
         gtk_window_unfullscreen(GTK_WINDOW(window));
-        
+
     return TRUE;
 }
 
@@ -271,14 +271,14 @@ static void parole_plugin_player_iface_init (ParoleProviderPlayerIface *iface)
     iface->set_fullscreen = parole_plugin_player_set_fullscreen;
 }
 
-static void 
-parole_plugin_player_media_state_changed_cb (ParoleGst *gst, const ParoleStream *stream, 
+static void
+parole_plugin_player_media_state_changed_cb (ParoleGst *gst, const ParoleStream *stream,
                                              ParoleState state, ParolePluginPlayer *player)
 {
     g_signal_emit_by_name (G_OBJECT (player), "state-changed", stream, state);
 }
 
-static void 
+static void
 parole_plugin_player_media_tag_cb (ParoleGst *gst, const ParoleStream *stream, ParolePluginPlayer *player)
 {
     g_signal_emit_by_name (G_OBJECT (player), "tag-message", stream);
@@ -291,7 +291,7 @@ parole_plugin_player_media_seeked_cb (ParoleGst *gst, ParolePluginPlayer *player
 }
 
 static gboolean
-parole_plugin_player_window_state_event  (GtkWidget *widget, 
+parole_plugin_player_window_state_event  (GtkWidget *widget,
                                           GdkEventWindowState *event,
                                           ParolePluginPlayer *player)
 {
@@ -317,23 +317,23 @@ parole_plugin_player_init (ParolePluginPlayer *player)
 {
     GtkWidget *window;
     player->priv = PAROLE_PLUGIN_PLAYER_GET_PRIVATE (player);
-    
+
     player->priv->gst = parole_gst_get ();
-    
+
     player->priv->state_changed = g_signal_connect (G_OBJECT (player->priv->gst), "media-state",
                         G_CALLBACK (parole_plugin_player_media_state_changed_cb), player);
-              
+
     player->priv->tag_message = g_signal_connect (G_OBJECT (player->priv->gst), "media-tag",
                         G_CALLBACK (parole_plugin_player_media_tag_cb), player);
-                        
+
     player->priv->seeked = g_signal_connect (G_OBJECT (player->priv->gst), "media-seeked",
                         G_CALLBACK (parole_plugin_player_media_seeked_cb), player);
 
-    player->priv->fullscreen = FALSE;                        
+    player->priv->fullscreen = FALSE;
     window = GTK_WIDGET(gtk_widget_get_toplevel (player->priv->gst));
-    g_signal_connect(   G_OBJECT(window), 
-                        "window-state-event", 
-                        G_CALLBACK(parole_plugin_player_window_state_event), 
+    g_signal_connect(   G_OBJECT(window),
+                        "window-state-event",
+                        G_CALLBACK(parole_plugin_player_window_state_event),
                         player );
 
     player->priv->packed = FALSE;
@@ -346,19 +346,19 @@ parole_plugin_player_finalize (GObject *object)
     ParolePluginPlayer *player;
 
     player = PAROLE_PLUGIN_PLAYER (object);
-    
+
     if ( G_IS_OBJECT (player->priv->gst) )
     {
-        if (g_signal_handler_is_connected (player->priv->gst, player->priv->state_changed)) 
+        if (g_signal_handler_is_connected (player->priv->gst, player->priv->state_changed))
             g_signal_handler_disconnect (player->priv->gst, player->priv->state_changed);
 
-        if (g_signal_handler_is_connected (player->priv->gst, player->priv->tag_message)) 
+        if (g_signal_handler_is_connected (player->priv->gst, player->priv->tag_message))
             g_signal_handler_disconnect (player->priv->gst, player->priv->tag_message);
-            
-        if (g_signal_handler_is_connected (player->priv->gst, player->priv->seeked)) 
+
+        if (g_signal_handler_is_connected (player->priv->gst, player->priv->seeked))
             g_signal_handler_disconnect (player->priv->gst, player->priv->seeked);
     }
-    
+
     if ( player->priv->packed && GTK_IS_WIDGET (player->priv->box))
         gtk_widget_destroy (player->priv->box);
 
@@ -369,8 +369,8 @@ ParolePluginPlayer *
 parole_plugin_player_new (void)
 {
     ParolePluginPlayer *player = NULL;
-    
+
     player = g_object_new (PAROLE_TYPE_PLUGIN_PLAYER, NULL);
-    
+
     return player;
 }
